@@ -6,11 +6,12 @@
 #  See LICENSE for more info.
 
 import numpy as np
-from qtpy.QtGui import QMatrix4x4, QVector3D
+from qtpy.QtGui import QMatrix4x4
 
 from OpenGL.GL import *
+
 from .gldrawable import GLDrawable
-from ..glprograms.text_management.textmanager import TextManager
+from ..text.textmanager import TextManager
 
 
 class TextGL(GLDrawable):
@@ -98,6 +99,11 @@ class TextGL(GLDrawable):
 
         tvs = np.array(text_vertices).reshape((-1, 3))
 
+        # Centered = Position represents center of the whole text, instead of the bottom left.
+        if self.centered:
+            ptp = np.ptp(tvs, axis=0)
+            tvs -= ptp / 2
+
         # Rotate vertices as required
         matrix = QMatrix4x4()
 
@@ -121,11 +127,6 @@ class TextGL(GLDrawable):
 
         tvs = np.array(tvs_response, np.float32).reshape((len(self.text), -1))
 
-        # Centered = Position represents center of the whole text, instead of the bottom left.
-        if self.centered:
-            ptp = np.ptp(tvs, axis=0)
-            tvs -= ptp / 2
-
         self.text_vertices = tvs.reshape((len(self.text), -1))
 
     def generate_buffers(self) -> None:
