@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-#  Copyright (c) 2019-2020 Gabriel Sanhueza.
+#  Copyright (c) 2019-2021 Gabriel Sanhueza.
 #
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
@@ -150,7 +150,7 @@ class ActionCollection:
         self.action_xsection.setIcon(IconCollection.get('flash_on.svg'))
         self.action_xsection.setShortcut('Ctrl+Shift+S')
 
-        self.action_grid = QAction('&Grid visibility', parent)
+        self.action_grid = QAction('&Grid settings', parent)
         self.action_grid.setIcon(IconCollection.get('grid.svg'))
         self.action_grid.setShortcut('Ctrl+G')
 
@@ -185,7 +185,3 @@ class ActionCollection:
         self.action_take_screenshot = QAction('&Take screenshot', parent)
         self.action_take_screenshot.setIcon(IconCollection.get('webcam.svg'))
         self.action_take_screenshot.setShortcut('Shift+S')
-
-        self.action_fix_wobbling = QAction('Fix &wobbling', parent)
-        self.action_fix_wobbling.setIcon(IconCollection.get('services.svg'))
-        self.action_fix_wobbling.setShortcut('Ctrl+K')
